==> durable-task-1.13-sources.jar: org/jenkinsci/plugins/durabletask/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.durabletask;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code WindowsBatchScript.windows_batch}: {@code Windows batch}.
     * 
     * @return
     *     {@code Windows batch}
     */
    public static String WindowsBatchScript_windows_batch() {
        return holder.format("WindowsBatchScript.windows_batch");
    }

    /**
     * Key {@code WindowsBatchScript.windows_batch}: {@code Windows batch}.
     * 
     * @return
     *     {@code Windows batch}
     */
    public static Localizable _WindowsBatchScript_windows_batch() {
        return new Localizable(holder, "WindowsBatchScript.windows_batch");
    }

    /**
     * Key {@code BourneShellScript.bourne_shell}: {@code Bourne shell}.
     * 
     * @return
     *     {@code Bourne shell}
     */
    public static String BourneShellScript_bourne_shell() {
        return holder.format("BourneShellScript.bourne_shell");
    }

    /**
     * Key {@code BourneShellScript.bourne_shell}: {@code Bourne shell}.
     * 
     * @return
     *     {@code Bourne shell}
     */
    public static Localizable _BourneShellScript_bourne_shell() {
        return new Localizable(holder, "BourneShellScript.bourne_shell");
    }

}

==> durable-task-1.14-sources.jar: org/jenkinsci/plugins/durabletask/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.durabletask;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code PowershellScript.powershell}: {@code PowerShell script}.
     * 
     * @return
     *     {@code PowerShell script}
     */
    public static String PowershellScript_powershell() {
        return holder.format("PowershellScript.powershell");
    }

    /**
     * Key {@code PowershellScript.powershell}: {@code PowerShell script}.
     * 
     * @return
     *     {@code PowerShell script}
     */
    public static Localizable _PowershellScript_powershell() {
        return new Localizable(holder, "PowershellScript.powershell");
    }

    /**
     * Key {@code WindowsBatchScript.windows_batch}: {@code Windows batch}.
     * 
     * @return
     *     {@code Windows batch}
     */
    public static String WindowsBatchScript_windows_batch() {
        return holder.format("WindowsBatchScript.windows_batch");
    }

    /**
     * Key {@code WindowsBatchScript.windows_batch}: {@code Windows batch}.
     * 
     * @return
     *     {@code Windows batch}
     */
    public static Localizable _WindowsBatchScript_windows_batch() {
        return new Localizable(holder, "WindowsBatchScript.windows_batch");
    }

    /**
     * Key {@code BourneShellScript.bourne_shell}: {@code Bourne shell}.
     * 
     * @return
     *     {@code Bourne shell}
     */
    public static String BourneShellScript_bourne_shell() {
        return holder.format("BourneShellScript.bourne_shell");
    }

    /**
     * Key {@code BourneShellScript.bourne_shell}: {@code Bourne shell}.
     * 
     * @return
     *     {@code Bourne shell}
     */
    public static Localizable _BourneShellScript_bourne_shell() {
        return new Localizable(holder, "BourneShellScript.bourne_shell");
    }

}
